@@ -440,7 +440,7 @@ def UpdateWidgetFromPypi():
                         #update
                         widgetReInstall(py_package, package_url, local_path)
                         widgetUpdateNotify(py_package, local_version, remote_version)
-                        store.updateWidgetVersion(it, local_path)
+                        store.updateWidgetInfo(it, local_path)
                         
                         # 如果daemon之前在运行且应该启动，则重启
                         if daemon_manager_instance and daemon_status.get("running", False):
